@@ -6,9 +6,9 @@ package Padre::Plugin::JavaScript;
 use 5.008;
 use strict;
 use warnings;
-use Class::Autouse 'Padre::Document::JavaScript';
+use Class::Autouse 'Padre::Plugin::JavaScript::Document';
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use base 'Padre::Plugin';
 
@@ -16,13 +16,13 @@ use base 'Padre::Plugin';
 # Padre::Plugin API Methods
 
 sub padre_interfaces {
-	'Padre::Plugin'          => 0.26,
-	'Padre::Document'        => 0.21,
+	'Padre::Plugin'          => 0.43,
+	'Padre::Document'        => 0.43,
 }
 
 sub registered_documents {
-	'application/javascript' => 'Padre::Document::JavaScript',
-	'application/json'       => 'Padre::Document::JavaScript',
+	'application/javascript' => 'Padre::Plugin::JavaScript::Document',
+	'application/json'       => 'Padre::Plugin::JavaScript::Document',
 }
 
 sub menu_plugins_simple {
@@ -30,18 +30,13 @@ sub menu_plugins_simple {
 	return ('JavaScript' => [
 		'JavaScript Beautifier', sub { $self->js_eautifier },
 		'JavaScript Minifier',   sub { $self->js_minifier },
+		'JavaScript Syntax Check', sub { $self->js_syntax_check },
 	]);
 }
 
 sub js_eautifier {
 	my ( $self ) = @_;
-	my $main = $self->main;
-
-	my $src = $main->current->text;
-	my $doc = $main->current->document;
-	return unless $doc;
-	my $code = $src ? $src : $doc->text_get;
-	return unless ( defined $code and length($code) );
+	my ($main,$src,$doc,$code) = $self->_get_code; return unless $code;
 
 	require JavaScript::Beautifier;
 	JavaScript::Beautifier->import('js_beautify');
@@ -61,13 +56,7 @@ sub js_eautifier {
 
 sub js_minifier {
 	my ( $self ) = @_;
-	my $main = $self->main;
-
-	my $src = $main->current->text;
-	my $doc = $main->current->document;
-	return unless $doc;
-	my $code = $src ? $src : $doc->text_get;
-	return unless ( defined $code and length($code) );
+	my ($main,$src,$doc,$code) = $self->_get_code; return unless $code;
 
 	require JavaScript::Minifier::XS;
 	JavaScript::Minifier::XS->import('minify');
@@ -82,6 +71,36 @@ sub js_minifier {
 	}
 }
 
+sub js_syntax_check
+{
+	my ( $self ) = @_;
+	my ($main,$src,$doc,$code) = $self->_get_code; return unless $code;
+
+	require JE;
+
+	if ( JE->new->parse($code) )
+	{
+		$main->message( Wx::gettext('Syntax ok'), 'Info' );
+	}
+	else
+	{
+		$main->message( Wx::gettext($@), 'Info' );
+	}
+}
+
+sub _get_code
+{
+	my ( $self ) = @_;
+	my $main = $self->main;
+
+	my $src = $main->current->text;
+	my $doc = $main->current->document;
+	return unless $doc;
+	my $code = $src ? $src : $doc->text_get;
+	return unless ( defined $code and length($code) );
+	return ($main,$src,$doc,$code);
+}
+
 1;
 __END__
 
@@ -106,6 +125,7 @@ Fayland Lam, C<< <fayland at gmail.com> >>
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008 Adam Kennedy & Fayland Lam all rights reserved.
+Copyright 2010 Padre team.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
